La librería es capaz de resolver sistemas de ecuaciones lineales y no lineales a través de los siguientes métodos:

Eliminación de Gauss
Gauss-Jordan
Crammer
Descomposición LU
Jacobi
Gauss-Seidel
Bisección


